#version 150

#moj_import <fog.glsl>
#moj_import <settings.glsl>

uniform sampler2D Sampler0;

uniform vec2 ScreenSize;
uniform vec4 ColorModulator;
uniform float FogStart;
uniform float FogEnd;
uniform vec4 FogColor;

in float vertexDistance;
in float depthLevel;
in vec4 vertexColor;
in vec2 texCoord0;

out vec4 fragColor;
	
void main() {
    vec4 color = texture(Sampler0, texCoord0) * vertexColor;
	
	if (color.a < 0.05) { discard; }
	
	//Shadow values
	vec3 shadow = vec3(0.248, 0.248, 0.248);
	
	//Inventory screen item count text shadow
	if (depthLevel == 300) { 
		if ( lessThan(vertexColor.rgb, shadow) == bvec3(true) ) { 
			color = vec4(0.063, 0.098, 0.18, 1); //ITEMBOX SHADOW BLUE
		}
	}
	
	// 432.03 - Dragged item count text (FRONT)
	/* if (depthLevel == 432.03) { 
		//color = vec4(1, 0, 0.5, 1); //PINK RED
	} */
	
	// 432 - Dragged item count text (SHADOW)
	if (depthLevel == 432) { 
		color = vec4(0.063, 0.098, 0.18, 1); //ITEMBOX SHADOW BLUE
		//color = vec4(0.098, 0.094, 0.082, color.a); //BLACK
	}
	
	//Disable shadow text in all gui screens
	if (depthLevel == 0 && greaterThan(vertexColor.rgb, shadow) == bvec3(true)) { 
		//This prevents missing text on the F3 screen and enchantment buttons
		if (color.r < 0.3 && color.g < 0.3 && color.b < 0.3) { discard; }
	}
	
	//Text on notification toasts and achievement messages
	//depthLevel == 800
	
	//Disable text shadow on hotbar
	if (depthLevel == 200) { 
		//Prevent text being missing in the advancements screen
		if (color.r < 0.3 && color.g < 0.3 && color.b < 0.3) { 
			color = vec4(0.098, 0.094, 0.082, 1); // BLACK
		}
	}
	
	//Darken text shadow in chat
	if (depthLevel == 100) { 
		if (color.r >= 0.231 && color.r <= 0.232 && color.g >= 0.231 && color.g <= 0.232) { 
			if (color.a > 0.5) { color.a = 0.5; }
			color = vec4(0, 0, 0, color.a); //BLACK
		}
	}
	
	//Disable text shadow on tooltips
	if (depthLevel == 400) { discard; }
		
    fragColor = linear_fog(color, vertexDistance, FogStart, FogEnd, FogColor);
}
