#version 150

#moj_import <fog.glsl>

in vec3 Position;
in vec4 Color;
in vec2 UV0;
in ivec2 UV2;

uniform sampler2D Sampler2;

uniform mat4 ModelViewMat;
uniform mat4 ProjMat;

uniform mat3 IViewRotMat;
uniform int FogShape;
uniform vec2 ScreenSize;

out float vertexDistance;
out float depthLevel;
out vec4 vertexColor;
out vec2 texCoord0;

bool isAt(int offset, int vID, int pos) 
	{ return (((vID == 1 || vID == 2) && offset == pos) || ((vID == 0 || vID == 3) && offset == (pos+8))); }

void main() {
	depthLevel = Position.z;
	vec3 pos = Position;

    vertexDistance = length((ModelViewMat * vec4(Position, 1.0)).xyz); //fog_distance(ModelViewMat, IViewRotMat * Position, FogShape);
    vertexColor = Color * texelFetch(Sampler2, UV2 / 16, 0); //vertexColor = Color;
    texCoord0 = UV0;
	
	//ColorMOD enchantment green
	if ( length(Color.rgb - vec3(0.471, 0.937, 0.106) ) < 0.1 ) 
	{ vertexColor = vec4(0.651, 0.949, 0, vertexColor.a ); }
	
	// get the size of a text pixel
	vec2 pixel = vec2(ProjMat[0][0], ProjMat[1][1]) / 2.0;
	
	// get the gui scale
	int guiScale = int(round(pixel.x / (1 / ScreenSize.x)));
	
	// get the size of the gui space
	vec2 guiSize = ScreenSize / guiScale;
	
	// get the vertex id for each specific character
	int vID = gl_VertexID % 4;
	
	// get the offset from the bottom 
	int offset = int(round(guiSize.y - Position.y));

	//Make rest of the outline text transparent
	if ( isAt(offset, vID, 26) || isAt(offset, vID, 27) ) { vertexColor = vec4(0.098, 0.094, 0.082, 0); }

	//Move xp level number shadow
	if ( length(Color.rgb - vec3(0.0, 0.0, 0.0) ) < 0.002 && isAt(offset, vID, 28) ) { 
		pos -= vec3(-0.8, 3.4, 0.0);
		vertexColor = vec4(0.098, 0.094, 0.082, 1); //BLACK
	}
	
	//Move and recolor xp level number
	if ( length(Color.rgb - vec3(0.501, 1.0, 0.125) ) < 0.002 && (isAt(offset, vID, 26) || isAt(offset, vID, 27) ) ) {
        //Move upwards
		pos -= vec3(0.0, 5.0, 0.0);
        
        //Recolor
        vertexColor = vec4(0.651, 0.949, 0, 1); //NEON GREEN
	}
	
	//Move text shadow on chat to be closer to font
	if (depthLevel == 100 || depthLevel == 432 || depthLevel == 200 || depthLevel == 0 || depthLevel == 300) 
		{ pos -= vec3(0.2, 0.2, 0.0); }
	
	gl_Position = ProjMat * ModelViewMat * vec4(pos, 1.0);
}
